@@ -40,6 +40,8 @@
 
 #define STOCK_QUOTE(sq) ((StockQuote *)(sq))
 
+#define NEVER_SENSITIVE		"never_sensitive"
+
 	enum {
 		WHITE,
 		RED,
@@ -164,6 +166,45 @@
 	static AtkObject* gtik_vbox_accessible_ref_child(AtkObject *obj, gint i);
 	/* end accessibility funcs and vars */
 
+	/*-----------------------------------------------------------------*/
+	/* set sensitive and setup NEVER_SENSITIVE appropriately */
+	static void hard_set_sensitive (GtkWidget *w, gboolean sensitivity)
+	{
+		gtk_widget_set_sensitive (w, sensitivity);
+		g_object_set_data (G_OBJECT (w), NEVER_SENSITIVE,
+				   GINT_TO_POINTER ( ! sensitivity));
+	}
+
+
+	/*-----------------------------------------------------------------*/
+	/* set sensitive, but always insensitive if NEVER_SENSITIVE is set */
+	static void soft_set_sensitive (GtkWidget *w, gboolean sensitivity)
+	{
+		if (g_object_get_data (G_OBJECT (w), NEVER_SENSITIVE))
+			gtk_widget_set_sensitive (w, FALSE);
+		else
+			gtk_widget_set_sensitive (w, sensitivity);
+	}
+
+
+	/*-----------------------------------------------------------------*/
+	static gboolean key_writable (PanelApplet *applet, const char *key)
+	{
+		gboolean writable;
+		char *fullkey;
+		static GConfClient *client = NULL;
+		if (client == NULL)
+			client = gconf_client_get_default ();
+
+		fullkey = panel_applet_gconf_get_full_key (applet, key);
+
+		writable = gconf_client_key_is_writable (client, fullkey, NULL);
+
+		g_free (fullkey);
+
+		return writable;
+	}
+
 	/*-----------------------------------------------------------------*/
 	static void load_fonts(StockData *stockdata)
 	{
@@ -230,9 +271,9 @@ static gint updateOutput(gpointer data)
 		stockdata->vfshandle = NULL;
 	}
 		
-	source_text_uri = g_strconcat("http://finance.yahoo.com/q?s=",
+	source_text_uri = g_strconcat("http://finance.yahoo.com/q/cq?s=",
 				      stockdata->props.tik_syms,
-				      "&d=v2",
+				      "&d=v1",
 				      NULL);
 
 	source_uri = gnome_vfs_uri_new(source_text_uri);
@@ -370,7 +411,7 @@ static gint updateOutput(gpointer data)
 
 		int  i=0;
 		int  j=0;
-		static char Text[256]="";
+		static char Text[1024]="";
 
 		if (line == NULL) {
 			Text[0] = '\0';
@@ -400,14 +441,14 @@ static gint updateOutput(gpointer data)
 	}
 
 	/*-----------------------------------------------------------------*/
-	static char *parseQuote(FILE *CONFIG, char line[512]) {
+	static char *parseQuote(FILE *CONFIG, char line[1024]) {
 		
-		char symbol[512];
-		char buff[512];
+		char symbol[1024];
+		char buff[1024];
 		char price[16];
 		char change[16];
 		char percent[16];
-		static char result[512]="";
+		static char result[1024]="";
 		int  linenum=0;
 		int AllOneLine=0;
 		int flag=0;
@@ -432,16 +473,16 @@ static gint updateOutput(gpointer data)
 		linenum++;
 
 		/* Skip the time... */
-		if (!AllOneLine) fgets(line,255,CONFIG);
+		if (!AllOneLine) fgets(line,1023,CONFIG);
 		else section = strtok(NULL,"|");
 		linenum++;
 
 		while (linenum < 8 ) {
 			if (!AllOneLine) {
-				fgets(line,255,CONFIG);
+				fgets(line,1023,CONFIG);
 			
 				if (strstr(line,
-			  	 "<td align=center nowrap colspan=2>")) {
+			  	 "td class=\"yfnc_tabledata1\" nowrap=\"nowrap\" align=\"center\">")) {
 					strcpy(change,"");
 					strcpy(percent,"");
 					linenum=100;
@@ -449,14 +490,14 @@ static gint updateOutput(gpointer data)
 			}
 			else {
 				section = strtok(NULL,"|");
-				if (strstr(section,
-			  	 "<td align=center nowrap colspan=2>")) {
+				if (section && strstr(section,
+			  	 "td class=\"yfnc_tabledata1\" nowrap=\"nowrap\" align=\"center\">")) {
 					strcpy(change,"");
 					strcpy(percent,"");
 					linenum=100;
 				}
 			}
-
+			
 			if (linenum == 2) { 
 				if (!AllOneLine) 
 					strcpy(price,extractText(line));
@@ -474,11 +515,12 @@ static gint updateOutput(gpointer data)
 					strcpy(percent,extractText(line));
 				else
 					strcpy(percent,extractText(section));
+				linenum = 100;
 			}
 			linenum++;
 		}
 		sprintf(result,"%s:%s:%s:%s",
-				symbol,price,change,percent);			
+				symbol,price,change,percent);		
 		return(result);
 
 	}
@@ -489,7 +531,7 @@ static gint updateOutput(gpointer data)
 	int configured(StockData *stockdata) {
 		int retVar;
 
-		char  buffer[512];
+		char  buffer[1024];
 		static FILE *CONFIG;
 
 		CONFIG = fopen((const char *)stockdata->configFileName,"r");
@@ -504,7 +546,7 @@ static gint updateOutput(gpointer data)
 				fgets(buffer, sizeof(buffer)-1, CONFIG);
 
 				if (strstr(buffer,
-				    "<td nowrap align=left><font face=arial size=-1><a href=\"/q\?s=")) {
+				    "<td class=\"yfnc_tabledata1\" nowrap=\"nowrap\" align=\"center\"><b><a href=\"/q?s=")) {
 
 				      setOutputArray(stockdata, parseQuote(CONFIG,buffer));
 				      retVar = 1;
@@ -828,7 +870,7 @@ static gint updateOutput(gpointer data)
 		GtkWidget *button;
 
 		button = GTK_WIDGET(data);
-		gtk_widget_set_sensitive(button,TRUE);
+		soft_set_sensitive(button,TRUE);
 	}
 
 	/*-----------------------------------------------------------------*/
@@ -958,9 +1000,9 @@ static gint updateOutput(gpointer data)
 					     
 		fonts_widget = g_object_get_data (G_OBJECT (button), "fonts_hbox");
 		colors_widget = g_object_get_data (G_OBJECT (button), "colors_hbox");
-		gtk_widget_set_sensitive (GTK_WIDGET (fonts_widget), 
+		soft_set_sensitive (GTK_WIDGET (fonts_widget), 
 					             !stockdata->props.use_default_theme);
-		gtk_widget_set_sensitive (GTK_WIDGET (colors_widget), 
+		soft_set_sensitive (GTK_WIDGET (colors_widget), 
 					             !stockdata->props.use_default_theme);
 		load_fonts(stockdata);
 	}
@@ -1098,7 +1140,7 @@ static gint updateOutput(gpointer data)
 	static void
 	selection_changed (GtkTreeSelection *selection, gpointer data) 
 	{
-		gtk_widget_set_sensitive (GTK_WIDGET (data), 
+		soft_set_sensitive (GTK_WIDGET (data), 
 						    gtk_tree_selection_get_selected (selection, NULL, NULL));
 						    
 	}
@@ -1112,7 +1154,7 @@ static gint updateOutput(gpointer data)
 		string = gtk_editable_get_chars (editable, 0, -1);
 		if (!string || !g_utf8_strlen (string, -1))
 			str = FALSE;
-		gtk_widget_set_sensitive (GTK_WIDGET (data), str);
+		soft_set_sensitive (GTK_WIDGET (data), str);
 		if (string) g_free (string);
 	}
 		
@@ -1255,7 +1297,7 @@ static gint updateOutput(gpointer data)
 		gtk_size_group_add_widget (size_group, button);
 		g_object_set_data (G_OBJECT (button), "entry", entry);
 		gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-		gtk_widget_set_sensitive (button, FALSE);
+		soft_set_sensitive (button, FALSE);
 		g_signal_connect (G_OBJECT (button), "clicked",
 				  G_CALLBACK (add_button_clicked), stockdata);
 		g_signal_connect (G_OBJECT (entry), "changed",
@@ -1266,11 +1308,15 @@ static gint updateOutput(gpointer data)
 		g_signal_connect (G_OBJECT (button), "clicked",
 				  G_CALLBACK (remove_symbol), stockdata);
 		gtk_box_pack_start(GTK_BOX(hbox),button,FALSE,FALSE,0);
-		gtk_widget_set_sensitive (button, FALSE);
+		soft_set_sensitive (button, FALSE);
 		g_signal_connect (G_OBJECT (selection), "changed",
 					   G_CALLBACK (selection_changed), button);
 
 		gtk_widget_show_all(mainhbox);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "tik_syms"))
+			hard_set_sensitive (mainhbox, FALSE);
+
 		return(mainhbox);
 
 	}
@@ -1376,6 +1422,7 @@ static gint updateOutput(gpointer data)
 		                                 GTK_RESPONSE_CLOSE);
 		gtk_dialog_set_has_separator (GTK_DIALOG (stockdata->pb), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (stockdata->pb), 5);
+		gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (stockdata->pb)->vbox),2);
 		gtk_widget_show (GTK_DIALOG (stockdata->pb)->vbox);
 		notebook = gtk_notebook_new ();
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (stockdata->pb)->vbox), notebook,
@@ -1411,6 +1458,9 @@ static gint updateOutput(gpointer data)
 		gtk_box_pack_start (GTK_BOX (hbox3), spin, FALSE, FALSE, 0);
 		label = gtk_label_new (_("minutes"));
 		gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "timeout"))
+			hard_set_sensitive (hbox2, FALSE);
 		
 		vbox = create_hig_catagory (behav_vbox, _("Scrolling"));
 		
@@ -1438,6 +1488,9 @@ static gint updateOutput(gpointer data)
 			gtk_option_menu_set_history (GTK_OPTION_MENU (option), 1);
 		else
 			gtk_option_menu_set_history (GTK_OPTION_MENU (option), 0);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "scroll_speed"))
+			hard_set_sensitive (hbox2, FALSE);
 		
 		hbox2 = gtk_hbox_new (FALSE, 6);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
@@ -1447,6 +1500,9 @@ static gint updateOutput(gpointer data)
 				  	  G_CALLBACK (scroll_toggled), stockdata);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
 							   stockdata->props.buttons);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "buttons"))
+			hard_set_sensitive (hbox2, FALSE);
 							   
 		hbox2 = gtk_hbox_new (FALSE, 6);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
@@ -1456,6 +1512,9 @@ static gint updateOutput(gpointer data)
 				           G_CALLBACK (rtl_toggled), stockdata);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
 							   !stockdata->props.scroll);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "scroll"))
+			hard_set_sensitive (hbox2, FALSE);
 							   
 		gtk_widget_show_all (behav_vbox);
 							   
@@ -1481,6 +1540,9 @@ static gint updateOutput(gpointer data)
 							   stockdata->props.output);
 		gtk_widget_show_all (hbox2);
 
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "output"))
+			hard_set_sensitive (hbox2, FALSE);
+
 		hbox2 = gtk_hbox_new (FALSE, 12);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox2, FALSE, FALSE, 0);
 		label = gtk_label_new_with_mnemonic (_("_Width:"));
@@ -1501,7 +1563,10 @@ static gint updateOutput(gpointer data)
 		gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
 		gtk_widget_show_all (hbox2);	
 		
-		 g_object_unref (size);
+		g_object_unref (size);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "width"))
+			hard_set_sensitive (hbox2, FALSE);
 		
 		vbox = create_hig_catagory (appear_vbox, _("Font and Colors"));
 		size = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
@@ -1516,6 +1581,9 @@ static gint updateOutput(gpointer data)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 							   stockdata->props.use_default_theme);
 		gtk_widget_show_all (hbox2);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "use_default_theme"))
+			hard_set_sensitive (hbox2, FALSE);
 					   
 		hbox2 = gtk_hbox_new (FALSE, 12);
 		font_hbox = hbox2;
@@ -1534,7 +1602,10 @@ static gint updateOutput(gpointer data)
 		g_signal_connect (G_OBJECT (font), "font_set",
                 		  G_CALLBACK (font_cb), stockdata);
                 gtk_size_group_add_widget (size2, font);
-		gtk_widget_show_all (hbox2);				  
+		gtk_widget_show_all (hbox2);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "font"))
+			hard_set_sensitive (hbox2, FALSE);
                	
 		color_vbox = gtk_vbox_new (FALSE, 6);
 		g_object_set_data (G_OBJECT (check), "colors_hbox", color_vbox);
@@ -1555,6 +1626,9 @@ static gint updateOutput(gpointer data)
 		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(ucolor_set_cb), stockdata);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "ucolor"))
+			hard_set_sensitive (hbox2, FALSE);
 				
 		hbox2 = gtk_hbox_new (FALSE, 12);
 		gtk_box_pack_start (GTK_BOX (color_vbox), hbox2, FALSE, FALSE, 0);
@@ -1571,6 +1645,9 @@ static gint updateOutput(gpointer data)
 		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(dcolor_set_cb), stockdata);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "dcolor"))
+			hard_set_sensitive (hbox2, FALSE);
 				
 		hbox2 = gtk_hbox_new (FALSE, 12);
 		gtk_box_pack_start (GTK_BOX (color_vbox), hbox2, FALSE, FALSE, 0);
@@ -1587,6 +1664,9 @@ static gint updateOutput(gpointer data)
 		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(fgcolor_set_cb), stockdata);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "fgcolor"))
+			hard_set_sensitive (hbox2, FALSE);
 				
 		hbox2 = gtk_hbox_new (FALSE, 12);
 		gtk_box_pack_start (GTK_BOX (color_vbox), hbox2, FALSE, FALSE, 0);
@@ -1603,6 +1683,9 @@ static gint updateOutput(gpointer data)
 		gtk_size_group_add_widget (size2, color);
 		g_signal_connect(G_OBJECT(color), "color_set",
 				G_CALLBACK(bgcolor_set_cb), stockdata);
+
+		if ( ! key_writable (PANEL_APPLET (stockdata->applet), "bgcolor"))
+			hard_set_sensitive (hbox2, FALSE);
 				
 		gtk_widget_show_all (vbox);
 				
@@ -1611,8 +1694,8 @@ static gint updateOutput(gpointer data)
 	
 		gtk_widget_show_all(stockdata->pb);
 		
-		gtk_widget_set_sensitive (font_hbox, !stockdata->props.use_default_theme);
-		gtk_widget_set_sensitive (color_vbox, !stockdata->props.use_default_theme);
+		soft_set_sensitive (font_hbox, !stockdata->props.use_default_theme);
+		soft_set_sensitive (color_vbox, !stockdata->props.use_default_theme);
 		
 		g_signal_connect (G_OBJECT (stockdata->pb), "response",
 				  G_CALLBACK (response_cb), stockdata);
@@ -1732,6 +1815,7 @@ static gint updateOutput(gpointer data)
 		gtk_tooltips_set_tip(stockdata->tooltips, event, _("Stock Ticker\nGet continuously updated stock quotes"), NULL);
 
 		access_drawing_area = stockdata->drawing_area = GTK_WIDGET (custom_drawing_area_new());
+		g_object_add_weak_pointer (G_OBJECT (access_drawing_area), (gpointer *)&access_drawing_area);
 		gtk_drawing_area_size(GTK_DRAWING_AREA (stockdata->drawing_area),
 						stockdata->props.width,-1);
 
@@ -1785,6 +1869,17 @@ static gint updateOutput(gpointer data)
 				                   gtik_applet_menu_verbs,
 				                   stockdata);
 
+		if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+			BonoboUIComponent *popup_component;
+
+			popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+
+			bonobo_ui_component_set_prop (popup_component,
+						      "/commands/Props",
+						      "hidden", "1",
+						      NULL);
+		}
+
 		/* KEEPING TIMER ID FOR CLEANUP IN DESTROY */
 		stockdata->drawTimeID = gtk_timeout_add(stockdata->props.scroll_speed,
 						        Repaint,stockdata);
@@ -1893,6 +1988,7 @@ static gint updateOutput(gpointer data)
 		char buff[128]="";
 		static char buff2[128]="";
 		char *var1, *var2, *var3, *var4;
+		char rise[1]="";
 
 		strcpy(buff,data);
 		var1 = strtok(buff,":");
@@ -1903,21 +1999,23 @@ static gint updateOutput(gpointer data)
 		if (!var3 || !var4)
 			return NULL;
 
-		if (var3[0] == '+') { 
+		if (var4[0] == '+') { 
 #if 0
 			if (stockdata->symbolfont)
 				var3[0] = 221;
 #endif
 			var4[0] = '(';
 			quote->color = GREEN;
+			sprintf (rise, "+");
 		}
-		else if (var3[0] == '-') {
+		else if (var4[0] == '-') {
 #if 0
 			if (stockdata->symbolfont)
 				var3[0] = 223;	
 #endif
 			var4[0] = '(';
 			quote->color = RED;
+			sprintf (rise, "-");
 		}
 		else {
 			var3 = g_strdup(_("(No"));
@@ -1925,7 +2023,7 @@ static gint updateOutput(gpointer data)
 			quote->color = WHITE;
 		}
 
-		sprintf(buff2,"%s %s)",var3,var4);
+		sprintf(buff2,"%s%s %s)",rise, var3,var4);
 		return(buff2);
 	}
 
@@ -1936,7 +2034,7 @@ static gint updateOutput(gpointer data)
 		char *change;
 		PangoRectangle rect;
 
-		price = splitPrice(param1);
+		price = splitPrice(param1);		
 		change = splitChange(stockdata, param1, &quote);
 
 		quote.price = g_strdup(price);
@@ -1956,7 +2054,7 @@ static gint updateOutput(gpointer data)
 			quote.changelen = 0;
 			quote.changeheight = 0;
 		}
-		
+		 
 
 #if 0
 		g_message("Param1: %s\nPrice: %s\nChange: %s\nColor: %d\n\n", param1, price, change, quote.color);
@@ -2122,7 +2220,11 @@ static gint updateOutput(gpointer data)
 	}
 
 	static AtkObject* gtik_vbox_accessible_ref_child(AtkObject *obj, gint i){
-		return (gtk_widget_get_accessible(access_drawing_area));
+		if (i == 0 && access_drawing_area)
+			return g_object_ref (gtk_widget_get_accessible(access_drawing_area));
+		else
+			return NULL;
+		
 	}
 
 	gchar* gtik_get_text(void) {
