@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.65 2003/12/07 16:11:21 kevinv Exp $ */
+/* $Id: weather.c,v 1.66 2003/12/15 17:34:55 damienc Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -1915,7 +1915,7 @@ const gchar *weather_info_get_temp_summary (WeatherInfo *info)
       degree = "F";
       
    g_snprintf(buf, sizeof (buf), "%d\302\260%s",
-	      (int)lrint(info->temp), degree);
+	      (int)floor(info->temp + 0.5), degree);
     
     return buf;
 }
