@@ -137,11 +137,10 @@ GetMemory (int Maximum, int data [5], LoadGraph *g)
 	
     assert ((mem.flags & needed_mem_flags) == needed_mem_flags);
 
-    
-    user    = rint (Maximum * (float)mem.user / mem.total);
-    shared  = rint (Maximum * (float)mem.shared / mem.total);
-    buffer  = rint (Maximum * (float)mem.buffer / mem.total);
-    cached = rint (Maximum * (float)mem.cached / mem.total);
+    user    = rint (Maximum * (float)mem.user / (float)mem.total);
+    shared  = rint (Maximum * (float)mem.shared / (float)mem.total);
+    buffer  = rint (Maximum * (float)mem.buffer / (float)mem.total);
+    cached = rint (Maximum * (float)mem.cached / (float)mem.total);
     
     data [0] = user;
     data [1] = shared;
