@@ -21,6 +21,8 @@
 #include <stickynotes_applet_callbacks.h>
 #include <stickynotes.h>
 
+#include <egg-screen-help.h>
+
 /* Applet Callback : Mouse button press on the applet. */
 gboolean applet_button_cb(GtkWidget *widget, GdkEventButton *event, StickyNotesApplet *applet)
 {
@@ -108,6 +110,13 @@ gboolean applet_change_bg_cb(PanelApplet *panel_applet, PanelAppletBackgroundTyp
 	return FALSE;
 }
 
+/* Applet Callback : Deletes the applet. */
+void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet)
+{
+	if (stickynotes->applets != NULL)
+		stickynotes->applets = g_list_remove (stickynotes->applets, applet);
+}		
+
 /* Menu Callback : Create a new sticky note */
 void menu_create_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
@@ -153,13 +162,24 @@ void menu_toggle_lock_cb(BonoboUIComponent *uic, const gchar *path, Bonobo_UICom
 void menu_preferences_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
 	stickynotes_applet_update_prefs();
+	gtk_window_set_screen(GTK_WINDOW(stickynotes->w_prefs), gtk_widget_get_screen(applet->w_applet));
 	gtk_window_present(GTK_WINDOW(stickynotes->w_prefs));
 }
 
 /* Menu Callback : Show help */
 void menu_help_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
-    	gnome_help_display("stickynotes_applet", "stickynotes-introduction", NULL);
+	GError *error = NULL;
+	egg_help_display_on_screen("stickynotes_applet", "stickynotes-introduction", gtk_widget_get_screen(applet->w_applet), &error);
+	if (error) {
+		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+							   _("There was an error displaying help: %s"), error->message);
+		g_signal_connect(G_OBJECT(dialog), "response", G_CALLBACK(gtk_widget_destroy), NULL);
+		gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+		gtk_window_set_screen (GTK_WINDOW(dialog), gtk_widget_get_screen(applet->w_applet));
+		gtk_widget_show(dialog);
+		g_error_free(error);
+	}
 }
 
 /* Menu Callback : Display About window */
@@ -296,8 +316,20 @@ void preferences_apply_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry,
 /* Preferences Callback : Response. */
 void preferences_response_cb(GtkDialog *dialog, gint response, gpointer data)
 {
-	if (response == GTK_RESPONSE_HELP)
-		gnome_help_display("stickynotes_applet", "stickynotes-introduction", NULL);
+	if (response == GTK_RESPONSE_HELP) {
+		GError *error = NULL;
+		egg_help_display_on_screen("stickynotes_applet", "stickynotes-advanced-settings", gtk_widget_get_screen(GTK_WIDGET(dialog)), &error);
+		if (error) {
+			GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+								   _("There was an error displaying help: %s"), error->message);
+			g_signal_connect(G_OBJECT(dialog), "response", G_CALLBACK(gtk_widget_destroy), NULL);
+			gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+			gtk_window_set_screen (GTK_WINDOW(dialog), gtk_widget_get_screen(GTK_WIDGET(dialog)));
+			gtk_widget_show(dialog);
+			g_error_free(error);
+		}
+	}
+
 	else
 		gtk_widget_hide(GTK_WIDGET(dialog));
 }
